/* xkeycaps, Copyright (c) 1994 Jamie Zawinski <jwz@netscape.com>
 *
 * This file describes the keycodes of a Data General AViiOn PC-style keyboard.
 * By David Axmark <davida@isil.detron.se>
 * Tested on a AViiON 300 running dgux 5.4 generic 
 */

static const KeyCode aviion300_codes [] = {
  /* Row 0 */
  9,
  8, 16, 24, 32,
  40, 48, 56, 64,
  72, 80, 87, 95,
  88, 96, 99,

  /* Row 2 */
  15, 23, 31, 39, 38, 47, 55, 62, 63, 71, 70, 79, 86, 103, 
  104, 111, 112,
  119, 120, 127, 133,

  /* Row 3 */
  14, 22, 30, 37, 46, 45, 54, 61, 68, 69, 78, 85, 92, 93,
  101, 102, 110,
  109, 118, 126, 125,

  /* Row 4 */
  21, 29, 28, 36, 44, 53, 52, 60, 67, 76, 77, 83, 91,
  108, 116, 117,

  /* Row 5 */
  19, 27, 35, 34, 43, 51, 50, 59, 66, 74, 75, 90,
  100,
  106, 115, 123, 122,

  /* Row 6 */
  18,
  26, 42, 58,
  89,
  98, 97, 107,
  113, 114
};
